@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.40 2004/05/29 14:12:09 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.44 2004/06/25 11:31:22 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -101,6 +101,25 @@ ephy_embed_base_init (gpointer g_class)
 			      2,
 			      G_TYPE_POINTER,
 			      G_TYPE_INT);
+/**
+ * EphyEmbed::ge-popup-blocked:
+ * @embed:
+ * @address: The requested URL
+ * @features: The requested features: for example, "height=400,width=200"
+ *
+ * The ::ge_popup_blocked signal is emitted when the viewed web page requests
+ * a popup window (with javascript:open()) but popup windows are not allowed.
+ **/
+		g_signal_new ("ge_popup_blocked",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, popup_blocked),
+			      NULL, NULL,
+			      ephy_marshal_VOID__STRING_STRING,
+			      G_TYPE_NONE,
+			      2,
+			      G_TYPE_POINTER,
+			      G_TYPE_POINTER);
 /**
  * EphyEmbed::ge-context-menu:
  * @embed:
@@ -142,7 +161,7 @@ ephy_embed_base_init (gpointer g_class)
  * @address: the new URL @embed is visiting
  *
  * The ::ge_location signal is emitted when @embed begins to load a new web
- * page. For example, if the user clicks on a link or enters an address of if
+ * page. For example, if the user clicks on a link or enters an address or if
  * the previous web page had JavaScript or a META REFRESH tag.
  *
  * The ::ge_location signal will be emitted even when @embed is simply
@@ -249,6 +268,25 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_FLOAT);
+/**
+ * EphyEmbed::ge-content-change:
+ * @embed:
+ * @uri: URI of the new content
+ *
+ * The ::ge_content_change signal is emitted when a new page content
+ * is being loadedinto the browser. It's a good place to do view
+ * related changes, for example to restore the zoom level of a page
+ * or to set an user style sheet.
+ **/
+		g_signal_new ("ge_content_change",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, content_change),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE,
+			      1,
+			      G_TYPE_STRING);
 
 		initialized = TRUE;
 	}
@@ -457,26 +495,25 @@ ephy_embed_get_js_status (EphyEmbed *embed)
 /**
  * ephy_embed_reload:
  * @embed: an #EphyEmbed
- * @flags: %EMBED_RELOAD_FORCE to bypass cache
+ * @force: %TRUE to bypass cache
  *
  * Reloads the web page being displayed in @embed.
  *
- * If @flags is %EMBED_RELOAD_FORCE, cache and proxy will be bypassed when
- * reloading the page. Otherwise, use %EMBED_RELOAD_NORMAL.
+ * If @force is %TRUE, cache and proxy will be bypassed when
+ * reloading the page.
  **/
 void
 ephy_embed_reload (EphyEmbed *embed,
-		   EmbedReloadFlags flags)
+		   gboolean force)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->reload (embed, flags);
+	iface->reload (embed, force);
 }
 
 /**
  * ephy_embed_set_zoom:
  * @embed: an #EphyEmbed
  * @zoom: the new zoom level
- * @reflow: %TRUE to reload the page
  *
  * Sets the zoom level for a web page.
  *
@@ -486,11 +523,10 @@ ephy_embed_reload (EphyEmbed *embed,
  **/
 void
 ephy_embed_set_zoom (EphyEmbed *embed,
-		     float zoom,
-		     gboolean reflow)
+		     float zoom)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->set_zoom (embed, zoom, reflow);
+	iface->set_zoom (embed, zoom);
 }
 
 /**
@@ -700,32 +736,30 @@ ephy_embed_has_automatic_encoding (EphyEmbed *embed)
 /**
  * ephy_embed_print:
  * @embed: an #EphyEmbed
- * @info: an #EmbedPrintInfo with all printing settings
  *
  * Sends a document to the printer.
  *
- * Normally one would use ephy_window_print() to display the print dialog, which
- * will build its own #EmbedPrintInfo and then call this function.
  **/
 void
-ephy_embed_print (EphyEmbed *embed,
-		  EmbedPrintInfo *info)
+ephy_embed_print (EphyEmbed *embed)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->print (embed, info);
+	iface->print (embed);
 }
 
 /**
- * ephy_embed_print_preview_close:
+ * ephy_embed_set_print_preview_mode:
  * @embed: an #EphyEmbed
+ * @preview_mode: Whether the print preview mode is enabled.
  *
- * Closes @embed's print preview dialog.
+ * Enable and disable the print preview mode.
  **/
 void
-ephy_embed_print_preview_close (EphyEmbed *embed)
+ephy_embed_set_print_preview_mode (EphyEmbed *embed,
+				   gboolean preview_mode)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->print_preview_close (embed);
+	iface->set_print_preview_mode (embed, preview_mode);
 }
 
 /**
