@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.45 2004/08/06 14:34:07 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.46 2004/08/23 12:42:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -91,7 +91,6 @@ enum
 	NODE_ACTIVATED,
 	NODE_SELECTED,
 	NODE_DROPPED,
-	SHOW_POPUP,
 	LAST_SIGNAL
 };
 
@@ -586,13 +585,6 @@ ephy_node_view_key_press_cb (GtkTreeView *treeview,
 			gtk_tree_selection_selected_foreach
 					(selection, path_toggled, view);
 		}
-	}	
-	else if ((event->state & GDK_SHIFT_MASK) &&
-	         (event->keyval == GDK_F10))
-	{
-		g_signal_emit (G_OBJECT (view), ephy_node_view_signals[SHOW_POPUP], 0);
-
-		return TRUE;
 	}
 	else if (view->priv->searchable_data_column != -1 && unicode)
 	{
@@ -810,7 +802,9 @@ ephy_node_view_button_press_cb (GtkWidget *treeview,
 
 		if (event->button == 3)
 		{
-			g_signal_emit (G_OBJECT (view), ephy_node_view_signals[SHOW_POPUP], 0);
+			gboolean retval;
+
+			g_signal_emit_by_name (view, "popup_menu", &retval);
 		}
 		else if (event->button == 1)
 		{
@@ -1652,15 +1646,6 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 			      2,
 			      G_TYPE_POINTER,
 			      G_TYPE_POINTER);
-	ephy_node_view_signals[SHOW_POPUP] =
-		g_signal_new ("show_popup",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyNodeViewClass, show_popup),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
 
 	g_type_class_add_private (object_class, sizeof (EphyNodeViewPrivate));
 }
