@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.84.4.2 2004/08/06 14:41:30 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.90 2004/08/06 14:34:07 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,6 +40,7 @@
 #include "toolbar.h"
 #include "ephy-session.h"
 #include "downloader-view.h"
+#include "egg-toolbars-model.h"
 #include "ephy-toolbars-model.h"
 #include "ephy-automation.h"
 #include "print-dialog.h"
@@ -53,12 +55,6 @@
 #include <unistd.h>
 #include <libgnomeui/gnome-client.h>
 
-#ifdef ENABLE_NAUTILUS_VIEW
-#include <bonobo/bonobo-generic-factory.h>
-#include "ephy-nautilus-view.h"
-#endif
-
-#define EPHY_NAUTILUS_VIEW_IID "OAFIID:GNOME_Epiphany_NautilusView"
 #define AUTOMATION_IID "OAFIID:GNOME_Epiphany_Automation"
 #define SERVER_TIMEOUT 60000
 
@@ -69,13 +65,14 @@ struct EphyShellPrivate
 	BonoboGenericFactory *automation_factory;
 	EphySession *session;
 	EphyBookmarks *bookmarks;
-	EphyToolbarsModel *toolbars_model;
+	EggToolbarsModel *toolbars_model;
 	EggToolbarsModel *fs_toolbars_model;
 	EphyExtensionsManager *extensions_manager;
 	GtkWidget *bme;
 	GtkWidget *history_window;
 	GObject *pdm_dialog;
 	GObject *prefs_dialog;
+	GObject *print_setup_dialog;
 	GList *del_on_exit;
 	guint server_timeout;
 };
@@ -150,12 +147,6 @@ ephy_automation_factory_cb (BonoboGenericFactory *this_factory,
 	{
 		return BONOBO_OBJECT (g_object_new (EPHY_TYPE_AUTOMATION, NULL));
 	}
-#ifdef ENABLE_NAUTILUS_VIEW
-	else if (strcmp (iid, EPHY_NAUTILUS_VIEW_IID) == 0)
-	{
-		return BONOBO_OBJECT (ephy_nautilus_view_new_component (shell));
-	}
-#endif
 
 	g_assert_not_reached ();
 
@@ -191,6 +182,7 @@ ephy_shell_init (EphyShell *shell)
 	shell->priv->bme = NULL;
 	shell->priv->history_window = NULL;
 	shell->priv->pdm_dialog = NULL;
+	shell->priv->print_setup_dialog = NULL;
 	shell->priv->toolbars_model = NULL;
 	shell->priv->fs_toolbars_model = NULL;
 	shell->priv->extensions_manager = NULL;
@@ -481,6 +473,12 @@ ephy_shell_finalize (GObject *object)
 		g_object_unref (shell->priv->prefs_dialog);
 	}
 
+	LOG ("Unref print setup dialog")
+	if (shell->priv->print_setup_dialog)
+	{
+		g_object_unref (shell->priv->print_setup_dialog);
+	}
+
 	LOG ("Unref bookmarks")
 	if (shell->priv->bookmarks)
 	{
@@ -548,17 +546,18 @@ ephy_shell_new_tab (EphyShell *shell,
 	EphyTab *tab;
 	EphyEmbed *embed;
 	gboolean in_new_window = TRUE;
-	gboolean grouped;
 	gboolean jump_to;
 	EphyEmbed *previous_embed = NULL;
 	GtkWidget *nb;
-	gint position;
+	int position = -1;
 	Toolbar *toolbar;
 
 	if (flags & EPHY_NEW_TAB_IN_NEW_WINDOW) in_new_window = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_EXISTING_WINDOW) in_new_window = FALSE;
 
-	jump_to = (flags & EPHY_NEW_TAB_JUMP);
+	in_new_window = in_new_window && !eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
+
+	jump_to = (flags & EPHY_NEW_TAB_JUMP) != 0;
 
 	if (!in_new_window && parent_window != NULL)
 	{
@@ -571,34 +570,24 @@ ephy_shell_new_tab (EphyShell *shell,
 
 	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
 
-	if (previous_tab)
+	if (previous_tab != NULL)
 	{
 		previous_embed = ephy_tab_get_embed (previous_tab);
 	}
 
-	grouped = ((flags & EPHY_NEW_TAB_OPEN_PAGE ||
-		    flags & EPHY_NEW_TAB_APPEND_GROUPED)) &&
-		  !(flags & EPHY_NEW_TAB_APPEND_LAST);
-
 	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_tab != NULL)
 	{
 		nb = ephy_window_get_notebook (window);
 		position = gtk_notebook_page_num (GTK_NOTEBOOK (nb),
 						  GTK_WIDGET (previous_tab)) + 1;
 	}
-	else
-	{
-		position = grouped ? EPHY_NOTEBOOK_INSERT_GROUPED : EPHY_NOTEBOOK_INSERT_LAST;
-	}
 
 	tab = ephy_tab_new ();
 	gtk_widget_show (GTK_WIDGET (tab));
 	embed = ephy_tab_get_embed (tab);
 
-	ephy_window_add_tab (window, tab,
-			     position,
-			     jump_to);
-	gtk_widget_show (GTK_WIDGET(window));
+	ephy_window_add_tab (window, tab, position, jump_to);
+	gtk_window_present (GTK_WINDOW (window));
 
 	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
 	    flags & EPHY_NEW_TAB_NEW_PAGE)
@@ -668,11 +657,16 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 	{
 		if (shell->priv->fs_toolbars_model == NULL)
 		{
+			gboolean success;
 			const char *xml;
 
 			shell->priv->fs_toolbars_model = egg_toolbars_model_new ();
 			xml = ephy_file ("epiphany-fs-toolbar.xml");
-			egg_toolbars_model_load (shell->priv->fs_toolbars_model, xml);
+			g_return_val_if_fail (xml != NULL, NULL);
+
+			success = egg_toolbars_model_load
+				(shell->priv->fs_toolbars_model, xml);
+			g_return_val_if_fail (success, NULL);
 		}
 
 		return G_OBJECT (shell->priv->fs_toolbars_model);
@@ -682,16 +676,22 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 		if (shell->priv->toolbars_model == NULL)
 		{
 			EphyBookmarks *bookmarks;
+			EggToolbarsModel *bookmarksbar_model;
 
+			shell->priv->toolbars_model = ephy_toolbars_model_new ();
+
+			/* get the bookmarks toolbars model. we have to do this
+			 * before loading the toolbars model from disk, since
+			 * this will connect the get_item_* signals
+			 */
 			bookmarks = ephy_shell_get_bookmarks (shell);
+			bookmarksbar_model = ephy_bookmarks_get_toolbars_model (bookmarks);
 
-			shell->priv->toolbars_model = ephy_toolbars_model_new (bookmarks);
-
-			g_object_set (bookmarks, "toolbars_model",
-				      shell->priv->toolbars_model, NULL);
+			/* ok, now we can load the model */
+			ephy_toolbars_model_load
+			(EPHY_TOOLBARS_MODEL (shell->priv->toolbars_model));
 		}
 
-
 		return G_OBJECT (shell->priv->toolbars_model);
 	}
 }
@@ -703,12 +703,19 @@ ephy_shell_get_extensions_manager (EphyShell *es)
 
 	if (es->priv->extensions_manager == NULL)
 	{
+		char *path;
+
 		/* Instantiate extensions manager */
 		es->priv->extensions_manager = ephy_extensions_manager_new ();
 
 		/* load the extensions */
 		ephy_extensions_manager_load_dir (es->priv->extensions_manager,
 						  EXTENSIONS_DIR);
+
+		path = g_build_filename (ephy_dot_dir (), "extensions", NULL);
+		ephy_extensions_manager_load_dir (es->priv->extensions_manager,
+						  path);
+		g_free (path);
 	}
 
 	return G_OBJECT (es->priv->extensions_manager);
@@ -806,3 +813,17 @@ ephy_shell_get_prefs_dialog (EphyShell *shell)
 
 	return shell->priv->prefs_dialog;
 }
+
+GObject *
+ephy_shell_get_print_setup_dialog (EphyShell *shell)
+{
+	if (shell->priv->print_setup_dialog == NULL)
+	{
+		shell->priv->print_setup_dialog = G_OBJECT (ephy_print_setup_dialog_new ());
+
+		g_object_add_weak_pointer (shell->priv->print_setup_dialog,
+					   (gpointer *) &shell->priv->print_setup_dialog);
+	}
+
+	return shell->priv->print_setup_dialog;
+}
